# tmodelviz

`tmodelviz` is a Python package for simulating and visualizing biochemical models using Tellurium in a jupyter notebook.

## Features
- Load and simulate SBML or antimony models.
- Calculate concentrations of chemical species, changes in concentration, rolling averages and fluxes at a range of timesteps.
- Interactively visualize simulations using Matplotlib and ipywidgets.

## Installation

```bash
pip install tmodelviz
